# Predicatability(high, low) & Preview(identical, transposed, substitute)

library(lme4)
library(lattice)
library(MASS)
library(plyr) 

rm(list=ls())
datafile = read.csv(file.choose(), sep = ",", dec = ".")
colnames(datafile)
nrow(datafile)
############################################################################################

col.Participant = 1     
col.Item = 2
col.Predictability = 3
col.Preview= 4
col.Condition= 5
measure = "GD"
datafile$depvar = datafile[,measure]
############################################################################################

datafile$pp = datafile[,col.Participant]
datafile$Item = datafile[,col.Item]
datafile$Predictability = datafile[,col.Predictability]
datafile$Preview = datafile[,col.Preview]
datafile$Condition = datafile[,col.Condition]

datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$Item = as.factor(datafile$Item)
datafile$Predictability = factor(datafile$Predictability, levels = c("H","L"))
datafile$Preview = factor(datafile$Preview, levels = c("I","T", "S"))
datafile$Condition = factor(datafile$Condition, levels = c("HI","HT","HS","LI","LT","LS"))
############################################################################################################

(table1 <- ddply(datafile, .(Predictability), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))
(table2<- ddply(datafile, .(Preview), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))
(table3 <- ddply(datafile, .(Predictability,Preview), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))
(table4 <- ddply(datafile, .(Preview,Predictability), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))
#############################################################################################################
#############################################################################################################

crit = 3
nrcolumns = ncol(datafile)   # We'll be using this for cleanup later
#let's first have a look
head(datafile)

# make a new datafile with fixation durations > 0 ms
between1 = datafile[datafile$depvar > 0, ]
head(between1)
#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)

#make a matrix with the standard deviations per subject and per condition for the dependent variable

sd.matrix = tapply(between1$depvar, list(between1$pp), sd, na.rm = T)

#add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}


#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}

# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0

#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)

result = between1[abs(between1$zscore) < 3,]

#you might want to clean up this data file by removing the added columns
result =  result[,1:nrcolumns]
datafile <-result
nrow(datafile)

#############################################################################################################
#############################################################################################################


# Do we need to log transform?
qqnorm(datafile$depvar)

# If yes
datafile$depvar = log(datafile$depvar)
qqnorm(datafile$depvar)
#############################################################################################################

contrasts(datafile$Predictability) <- contr.sdif(2) 
contrasts(datafile$Preview) <- contr.sdif(3) 
#############################################################################################################
#############################################################################################################

full = lmer(depvar ~ Predictability * Preview + (1+Predictability*Preview|pp) + (1+Predictability*Preview|Item), datafile)
summary(full, corr = FALSE)
confint(full)

depvar.lmer1 = lmer(depvar ~ Predictability * Preview + (1+Predictability*Preview|pp) + (1+Predictability+Preview|Item), datafile)
summary(depvar.lmer1, corr = FALSE)
confint(depvar.lmer1)

depvar.lmer2 = lmer(depvar ~ Predictability * Preview + (1+Predictability*Preview|pp) + (1+Preview|Item), datafile)
summary(depvar.lmer2, corr = FALSE)
confint(depvar.lmer2)

depvar.lmer3 = lmer(depvar ~ Predictability * Preview + (1+Predictability*Preview|pp) + (1+Predictability|Item), datafile)
summary(depvar.lmer3, corr = FALSE)
confint(depvar.lmer3)

depvar.lmer4 = lmer(depvar ~ Predictability * Preview + (1+Predictability*Preview|pp) + (1|Item), datafile)
summary(depvar.lmer4, corr = FALSE)
confint(depvar.lmer4)

depvar.lmer5 = lmer(depvar ~ Predictability * Preview + (1+Predictability+Preview|pp) + (1+Predictability+Preview|Item), datafile)
summary(depvar.lmer5, corr = FALSE)
confint(depvar.lmer5)

depvar.lmer6 = lmer(depvar ~ Predictability * Preview + (1+Predictability+Preview|pp) + (1+Preview|Item), datafile)
summary(depvar.lmer6, corr = FALSE)
confint(depvar.lmer6)

depvar.lmer7 = lmer(depvar ~ Predictability * Preview + (1+Predictability+Preview|pp) + (1+Predictability|Item), datafile)
summary(depvar.lmer7, corr = FALSE)
confint(depvar.lmer7)

depvar.lmer8 = lmer(depvar ~ Predictability * Preview + (1+Predictability+Preview|pp) + (1|Item), datafile)
summary(depvar.lmer8, corr = FALSE)
confint(depvar.lmer8)

depvar.lmer9 = lmer(depvar ~ Predictability * Preview + (1+Preview|pp) + (1|Item), datafile)
summary(depvar.lmer9, corr = FALSE)
confint(depvar.lmer9)

depvar.lmer10 = lmer(depvar ~ Predictability * Preview + (1+Predictability|pp) + (1|Item), datafile)
summary(depvar.lmer10, corr = FALSE)
confint(depvar.lmer10)

depvar.lmer11 = lmer(depvar ~ Predictability*Preview + (1|pp) + (1|Item), datafile)
summary(depvar.lmer11, corr = FALSE)
confint(depvar.lmer11)
###############################################################################################################

#For (1,0) data

model1 = glmer(depvar ~ Predictability * Preview + (1|pp)+ (1|Item) ,datafile, family=binomial,control = glmerControl(optCtrl = list(maxfun = 20000)))
summary(model1)

#############################################################################################################
#############################################################################################################

##simple effect analysis to see the transposed prime effect.
contrast.matrix <- matrix(c(
  -1, 1, 0, 0, 0, 0,          # H.T-I
  0, 0, 0, -1, 1, 0,           # L.T-I
  0, -1, +1, 0, 0, 0,         # H.S-T  
  0, 0, 0, 0, -1, +1 ), 6, 4, # L.S-T
  dimnames=list(c("HI", "HT", "HS", "LI", "LT", "LS"), 
                c("H.T-I", "L.T-I","H.S-T","L.S-T")))

inv.contrast.matrix <- matrix(t(ginv(contrast.matrix)), 6, 4,
                              dimnames=list(c("HI", "HT", "HS", "LI", "LT", "LS"), 
                                            c("H.T-I", "L.T-I","H.S-T","L.S-T")))

(contrasts(datafile$Condition) <- fractions(inv.contrast.matrix))

depvar.lmer1 = lmer(depvar ~ Condition + (1|pp)+(1|Item), datafile)
summary(depvar.lmer1, corr = FALSE)

depvar.glmer1 = glmer(depvar ~  Condition +(1|pp) + (1|Item), datafile, family=binomial)
summary(depvar.glmer1, corr = FALSE)
############################################################################################################
############################################################################################################

##simple effect analysis to see the predictabiltiy effect under three preview condition.
contrast.matrix <- matrix(c(
  -1, 0, 0, 1, 0, 0,         # I.L-H
  0, -1, 0, 0, 1, 0,         # T.L-H
  0, 0, -1, 0, 0, 1), 6, 3,  # S.L-H
  dimnames=list(c("HI", "HT", "HS", "LI", "LT", "LS"), 
                c("I.L-H", "T.L-H", "S.L-H")))

inv.contrast.matrix <- matrix(t(ginv(contrast.matrix)), 6, 3,
                              dimnames=list(c("HI", "HT", "HS", "LI", "LT", "LS"), 
                                            c("I.L-H", "T.L-H", "S.L-H")))
(contrasts(datafile$Condition) <- fractions(inv.contrast.matrix))

depvar.lmer1 = lmer(depvar ~ Condition + (1|pp) + (1|Item), datafile)
summary(depvar.lmer1, corr = FALSE)

depvar.glmer1 = glmer(depvar ~  Condition +(1|pp) + (1|Item), datafile, family=binomial)
summary(depvar.glmer1, corr = FALSE)

############################################################################################################
############################################################################################################
# Bayes Analysis for fixation measures
rm(list=ls())
datafile = read.csv(file.choose(), sep = ",", dec = ".")

library(BayesFactor)
iterations <- 100000  
rscaleFixed <- 0.5    # scaling factor for g-priors for fixed effects - this is the same as the default (cauchy)
whichRandom <- c("Participant,Item")  # specify random effects

colnames(datafile)
datafile$depvar = datafile[,6] 
datafile$depvar = as.numeric(datafile$depvar)

sum(is.na(datafile$depvar))
datafile <- na.omit(datafile)
nrow(datafile)

qqnorm(datafile$depvar)
datafile$depvar = log(datafile$depvar)
qqnorm(datafile$depvar)

contrasts(datafile$Predictability) <- contr.sdif(2) 
contrasts(datafile$Preview) <- contr.sdif(2) 

bfFull <- lmBF(depvar ~ Predictability*Preview + Participant + Participant + Item, rscaleFixed=rscaleFixed, whichRandom = whichRandom, iterations = iterations, datafile)
bfFull

Nointeraction <- lmBF(depvar ~Predictability + Preview + Participant + Item, rscaleFixed=rscaleFixed, whichRandom = whichRandom, iterations = iterations, datafile)
Nointeraction 

bfFull/Nointeraction
Nointeraction/bfFull
############################################################################################################
############################################################################################################
library(yarrr)
datafile = read.csv(file.choose(), sep = ",", dec = ".")
colnames(datafile)

measure = "FFD"
datafile$depvar = datafile[,measure]
datafile$Predictability = factor(datafile$Predictability, levels = c("High","Low"))
datafile$Preview = factor(datafile$Preview, levels = c("Identical","Transposed","Substituted"))

plot <- pirateplot(formula = depvar ~ Preview +Predictability, 
           datafile,
           ylab = "First fixation duration (ms)",
           theme=1,
           point.o = .8,
           point.pch = 21,
           bar.f.o = 0,
           bean.b.o = .5,
           inf.f.o = 1,
           inf.b.o = 1,
           quant = c(.25, .75),
           quant.col = "black",
           quant.lwd = 2,
           avg.line.o = 1,
           avg.line.lwd = 2,
           gl.col = "white",
           cex.axis = .8,
           cex.names = .8,
           plot = TRUE)

#if plot=FALSE, then we can get the main statistical result using function below.
plot$summary 
